==> fop2-2.24-debian-x86_64.tgz: fop2/html/js/lang_pl.js <==
// By Robert Jedrachowicz

lang['incoming_call']      = 'Połączenie przychodzące';
lang['connecting_server']  = 'Łączenie z serwerem, próba ';

lang['from_queue']         = "Z kolejki:";
lang['number']             = "Numer:";
lang['name']               = "Nazwa:";

lang['dial']               = 'Połącz';
lang['transfer_vmail']     = 'Przekaż do Mailbox';
lang['transfer_external']  = 'przekaż na komórkę';
lang['attendant_transfer'] = 'Przekaż';
lang['spy']                = 'Słuchaj';
lang['whisper']            = 'Słuchaj i szepcz';
lang['pickup']             = "Odbierz połacznie";
lang['hangup']             = 'Rozłącz';
lang['filter']             = 'Filtr';

lang['enter_sec_code']     = 'Login - szczegóły';
lang['exten']              = 'Abonent:';
lang['password']           = 'Hasło:';

lang['confirm_hangup']     = 'Potwierdź rozłączenie';
lang['areyousure']         = 'czy jesteś pewien?';
lang['yes']                = 'Tak';
lang['no']                 = 'Nie';

lang['paused']             = 'Pauza';
lang['set_information']    = 'Ustaw informację';
lang['member_of']          = 'członek grupy ';
lang['not_available']      = 'System obecnie niedostępny';
lang['not_connect']        = 'Brak połączenia z serwerem';
lang['one_moment']         = 'Proszę czekać';
lang['no_results']         = 'Brak resultatów';

lang['toggle_lock']        = 'Zablokuj/odblokuj konferencję';
lang['toggle_muteall']     = 'Wycisz/Nie wyciszaj wszystkich';
lang['available']          = 'Dostępny';
lang['phonebook']          = 'Ksiązka telefoniczna';
lang['toggle_mute']        = 'Przełącz wyciszenie';
lang['kick']               = 'Wyrzuć usera';
lang['record']             = 'nagraj rozmowę';
lang['presence_noti']      = 'Obecność komunikatu';

lang['queues']             = 'Kolejki';
lang['extensions']         = 'Abonenci';
lang['trunks']             = 'Linie';
lang['conferences']        = 'Konferencje';
lang['other']              = 'Inne';
lang['enter_state']        = 'Wprowadź wartość';
lang['parkingslots']       = 'Sloty parkowania';

lang['enter_reg_code']     = 'Wprowadź kod:';
lang['reg_code']     = 'Registration Code:';
lang['reg_name']     = 'Registration Name:';

lang['remove_member']      = 'Usuń abonenta';
lang['remove_member_from'] = 'Usuń z ';
lang['pause_member']       = 'Zatrzymaj abonenta';
lang['unpause_member']     = 'Wznów abonenta';
lang['add_member']         = 'Dodaj do ';
lang['pickup_call']        = 'Odbierz połącznenie';
lang['email_user']         = 'Wyślij email';
lang['send_sms']           = 'Wysłać sms';
lang['message']            = 'Wiadomość:';
lang['sending']            = 'Wysyłanie...';
lang['noResponse']         = 'bez odpowiedzi.';

lang['chat']               = 'Chat';
lang['notlogged']          = 'Abonent nie zalogowany. Zachowuję wiadomość';
lang['me']                 = 'Ja';
lang['clearchat']          = 'Wyczyśc okno Chatu';
lang['note']               = 'notatka';
lang['toggle_sound']       = 'Przełącz dźwięk';
lang['says']               = 'mówi';

lang['agents']             = 'Agenci:';
lang['calls']              = 'Połącznenia oczekujące:';
lang['call_connected']     = 'Mów do';
lang['changeDisplayType']  = 'Zmień typ wyświetlania';

lang['voicemail']          = 'Voicemail';
lang['vmail_new']          = 'Nowe';
lang['vmail_old']          = 'Stare';
lang['vmail_work']         = 'Praca';
lang['vmail_family']       = 'Rodzina';
lang['vmail_friends']      = 'przyjaciele';
lang['vmail_number']       = 'Nie.';
lang['vmail_date']         = 'Data';
lang['vmail_callerid']     = 'Dzwoniący';
lang['vmail_duration']     = 'Czas trwania';

lang['preferences']        = 'Ustawienia';
lang['summary']            = 'Podsumowanie';
lang['detailed']           = 'Szczegółowo';

lang['inactive_line']      = 'Linia %d nieaktywna';
lang['inuse']              = '%d linia w użyciu';
lang['vmail_count']        = 'Nowe %d, Stare %d';
lang['logout']             = 'Wyloguj'

lang['prefSounds']         = 'Dźwięki';
lang['prefDisplay']        = 'Ekran';

lang['labelSoundChat']     = 'Dźwięk Chatu';
lang['labelSoundQueue']    = 'Dźwięk kolejki';
lang['labelSoundRing']     = 'Dźwięk dzwonka';

lang['labelDisplayQueue']          = 'Domyślny widok kolejki:';
lang['labelDisplayDynamicLine']    = 'Dynamiczna linia:';
lang['labelDisplayNotifyDuration'] = 'Czas wyświetlania powiadomienia:';
lang['labelDisplayLanguage']       = 'Język:';


// Internationalization strings DATE
dateFormat.i18n = {
    dayNames: [
        "Nie", "Pon", "Wto", "Śro", "Czw", "Pią", "Sob",
        "Niedziela", "Poniedziałek", "Wtorek", "Środa", "Czwartek", "Piątek", "Sobota"
    ],
    monthNames: [
        "Sty", "Lut", "Mar", "Kwi", "Maj", "Cze", "Lip", "Sie", "Wrz", "Paź", "Lis", "Gru",
        "Styczeń", "Luty", "Marzec", "Kwiecień", "Maj", "Czerwiec", "Lipiec", "Sierpień", "Wrzesień", "Październik", "Listopad", "Grudzień"
    ]
};

==> fop2-2.29.03-debian-x86_64.tgz: fop2/html/js/lang_pl.js <==
// By Robert Jedrachowicz

lang['incoming_call']      = 'Połączenie przychodzące';
lang['connecting_server']  = 'Łączenie z serwerem, próba ';

lang['from_queue']         = "Z kolejki:";
lang['number']             = "Numer:";
lang['name']               = "Nazwa:";

lang['dial']               = 'Połącz';
lang['transfer_vmail']     = 'Przekaż do Mailbox';
lang['transfer_external']  = 'Przekaż na komórkę';
lang['attendant_transfer'] = 'Nadzorowanych Przekaż';
lang['blind_transfer']     = 'Przekaż';
lang['spy']                = 'Słuchaj';
lang['whisper']            = 'Słuchaj i szepcz';
lang['pickup']             = "Odbierz połacznie";
lang['hangup']             = 'Rozłącz';
lang['filter']             = 'Filtr';

lang['enter_sec_code']     = 'Login - szczegóły';
lang['exten']              = 'Abonent:';
lang['password']           = 'Hasło:';

lang['confirm_hangup']     = 'Potwierdź rozłączenie';
lang['areyousure']         = 'czy jesteś pewien?';
lang['yes']                = 'Tak';
lang['no']                 = 'Nie';
lang['cancel']             = 'Anuluj';
lang['accept']             = 'Akceptować';

lang['paused']             = 'Pauza';
lang['set_information']    = 'Ustaw informację';
lang['set_penalty']        = 'Kara';
lang['member_of']          = 'członek grupy ';
lang['not_available']      = 'System obecnie niedostępny';
lang['not_connect']        = 'Brak połączenia z serwerem';
lang['one_moment']         = 'Proszę czekać';
lang['no_results']         = 'Brak resultatów';

lang['toggle_lock']        = 'Zablokuj/odblokuj konferencję';
lang['toggle_muteall']     = 'Wycisz/Nie wyciszaj wszystkich';
lang['available']          = 'Dostępny';
lang['phonebook']          = 'Ksiązka telefoniczna';
lang['toggle_mute']        = 'Przełącz wyciszenie';
lang['kick']               = 'Wyrzuć usera';
lang['record']             = 'nagraj rozmowę';
lang['presence_noti']      = 'Obecność komunikatu';

lang['queues']             = 'Kolejki';
lang['extensions']         = 'Abonenci';
lang['trunks']             = 'Linie';
lang['conferences']        = 'Konferencje';
lang['other']              = 'Inne';
lang['enter_state']        = 'Wprowadź wartość';
lang['parkingslots']       = 'Sloty parkowania';

lang['enter_reg_code']     = 'Wprowadź kod:';
lang['reg_code']     = 'Registration Code:';
lang['reg_name']     = 'Registration Name:';

lang['remove_member']      = 'Usuń abonenta';
lang['remove_member_from'] = 'Usuń z ';
lang['pause_member']       = 'Zatrzymaj abonenta';
lang['unpause_member']     = 'Wznów abonenta';
lang['add_member']         = 'Dodaj do ';
lang['pickup_call']        = 'Odbierz połącznenie';
lang['email_user']         = 'Wyślij email';
lang['send_sms']           = 'Wysłać sms';
lang['message']            = 'Wiadomość:';
lang['sending']            = 'Wysyłanie...';
lang['noResponse']         = 'bez odpowiedzi.';
lang['calls_taken']        = 'Zwraca podjęte:';
lang['penalty']            = 'Kara:';

lang['chat']               = 'Chat';
lang['notlogged']          = 'Abonent nie zalogowany. Zachowuję wiadomość';
lang['me']                 = 'Ja';
lang['clearchat']          = 'Wyczyśc okno Chatu';
lang['note']               = 'notatka';
lang['toggle_sound']       = 'Przełącz dźwięk';
lang['says']               = 'mówi';

lang['agents']             = 'Agenci: %d';
lang['calls']              = 'Połącznenia oczekujące: %s';
lang['call_connected']     = 'Mów do';
lang['changeDisplayType']  = 'Zmień typ wyświetlania';

lang['voicemail']          = 'Voicemail';
lang['vmail_new']          = 'Nowe';
lang['vmail_old']          = 'Stare';
lang['vmail_work']         = 'Praca';
lang['vmail_family']       = 'Rodzina';
lang['vmail_friends']      = 'przyjaciele';
lang['vmail_number']       = 'Nie.';
lang['vmail_date']         = 'Data';
lang['vmail_callerid']     = 'Dzwoniący';
lang['vmail_duration']     = 'Czas trwania';
lang['play']               = 'Reprodukować';
lang['download']           = 'Pobierz';

lang['preferences']        = 'Ustawienia';
lang['summary']            = 'Podsumowanie';
lang['detailed']           = 'Szczegółowo';

lang['inactive_line']      = 'Linia %d nieaktywna';
lang['inuse']              = '%d linia w użyciu';
lang['vmail_count']        = 'Nowe %d, Stare %d';
lang['logout']             = 'Wyloguj'

lang['prefSounds']         = 'Dźwięki';
lang['prefDisplay']        = 'Ekran';
lang['prefPopup']          = 'Popup';
lang['prefPhone']          = 'Telefon';

lang['labelSoundChat']     = 'Dźwięk Chatu';
lang['labelSoundQueue']    = 'Dźwięk kolejki';
lang['labelSoundRing']     = 'Dźwięk dzwonka';

lang['labelDisplayQueue']          = 'Domyślny widok kolejki';
lang['labelDisplayDynamicLine']    = 'Dynamiczna linia';
lang['labelDisplayNotifyDuration'] = 'Czas wyświetlania powiadomienia';
lang['labelDisplayLanguage']       = 'Język';
lang['labelAutoPopup']             = 'Auto Popup';
lang['labelAutoAnswer']            = 'Automatyczna Odpowiedź';

lang['close']                      = 'Zamknąć';
lang['recordings']                 = 'Nagrania';
lang['cdrrecords']                 = 'Historię Połączeń';

// Internationalization strings DATE
dateFormat.i18n = {
    dayNames: [
        "Nie", "Pon", "Wto", "Śro", "Czw", "Pią", "Sob",
        "Niedziela", "Poniedziałek", "Wtorek", "Środa", "Czwartek", "Piątek", "Sobota"
    ],
    monthNames: [
        "Sty", "Lut", "Mar", "Kwi", "Maj", "Cze", "Lip", "Sie", "Wrz", "Paź", "Lis", "Gru",
        "Styczeń", "Luty", "Marzec", "Kwiecień", "Maj", "Czerwiec", "Lipiec", "Sierpień", "Wrzesień", "Październik", "Listopad", "Grudzień"
    ]
};
